// -*- C++ -*-
#include "tao/Stub_Factory.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_Stub_Factory::~TAO_Stub_Factory ()
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
